/*
 * gc global variable provides access to GUI Composer infrastructure components and project information.
 * For more information, please see the Working with Javascript guide in the online help.
 */
var gc = gc || {};
gc.services = gc.services || {};

//Initialize Global Variables
defaultEVM = 1;
adcrange_EVM1 = 0;
adcrange_EVM2 = 0;
adcrange_EVM3 = 0;
adcrange_EVM4 = 0;
is20Bit = -1; //default to unused value in case of error

let saveText = function(fname, text) {
    let blob = new Blob([text], {
        type: 'text/plain;charset=utf-8'
    });
    saveAs(blob, fname);

    return false;
}

/*
*  Boilerplate code for creating computed data bindings
*/
document.addEventListener('gc-databind-ready', function() 
{
    /* 
	*   Add custom computed value databindings here, using the following method:
	*
    *   function gc.databind.registry.bind(targetBinding, modelBinding, [getter], [setter]);
	*
	*   param targetBinding - single binding string or expression, or array of binding strings for multi-way binding.
	*   param modelBinding - single binding string or expression, or array of binding strings for multi-way binding.
	*   param getter - (optional) - custom getter function for computing the targetBinding value(s) based on modelBinding value(s).
	*   param setter - (optional) - custom setter function for computing the modelBinding value(s) based on targetBinding value(s).
    */
	
	// For example, a simple computed values based on simple expression
	// gc.databind.registry.bind('widget.id.propertyName', "targetVariable == 1 ? 'binding is one' : 'binding is not one'");
	
	// Or a custom two-way binding with custome getter and setter functions.  (setter is optional)  (getter only indicates one-way binding)
	// gc.databind.registry.bind('widget.id.propertyName', "targetVariable", function(value) { return value*5/9 + 32; }, function(value) { (return value-32)*9/5; });
	
	// Event 1 to n bindings
	/* 
    gc.databind.registry.bind('widget.date.value', 
        // dependant bindings needed in order to compute the date, in name/value pairs.
        {
            weekday: 'widget.dayOfWeek.selectedText',
            day: 'widget.dayOfMonth.value',
            month: 'widget.month.selectedText',
            year: 'widget.year.value'
        }, 
        // getter for date computation
        function(values) 
        {
            // compute and return the string value to bind to the widget with id 'date'
            return values.weekday + ', ' + values.month + ' ' + values.day + ', ' + values.year;
        }
    ); 
	*/
	
	//bind results registers to plots
    // gc.databind.registry.bind('widget.ti_widget_scalargraph_VSHUNT.value_0', 'ti_model_register.vshunt_register.vshunt',
    //     function(value) 
    //     {
    //         let result = value;
    //         return result;
    //     }
    // ); 
    // gc.databind.registry.bind('widget.ti_widget_scalargraph_VBUS.value_0', 'ti_model_register.vbus_register.vbus',
    //     function(value) 
    //     {
    //         let result = value;
    //         return result;
    //     }
    // ); 
    // gc.databind.registry.bind('widget.ti_widget_scalargraph_DIETEMP.value_0', 'ti_model_register.dietemp_register.temp',
    //     function(value) 
    //     {
    //         let result = value;
    //         return result;
    //     }
    // ); 
    // gc.databind.registry.bind('widget.ti_widget_scalargraph_CURRENT.value_0', 'ti_model_register.current_register.current',
    //     function(value) 
    //     {
    //         let result = value;
    //         return result;
    //     }
    // ); 
    // gc.databind.registry.bind('widget.ti_widget_scalargraph_POWER.value_0', 'ti_model_register.power_register.power',
    //     function(value) 
    //     {
    //         let result = value;
    //         return result;
    //     }
    // ); 
    // gc.databind.registry.bind('widget.ti_widget_scalargraph_ENERGY.value_0', 'ti_model_register.energy_register.energy',
    //     function(value) 
    //     {
    //         let result = value;
    //         return result;
    //     }
    // ); 
    // gc.databind.registry.bind('widget.ti_widget_scalargraph_CHARGE.value_0', 'ti_model_register.charge_register.charge',
    //     function(value) 
    //     {
    //         let result = value;
    //         return result;
    //     }
    // ); 
    
    // Bind settings to specific devices
 	gc.databind.registry.bind('widget.ti_widget_checkbox_ENERGY.checked', 'widget.ti_model_register.$selectedDevice', 
     	function(deviceName)
     	{
            if(deviceName === "INA237_238" || deviceName === "INA239")
            {
                templateObj.$.ti_widget_checkbox_ENERGY.disabled = true;
                templateObj.$.ti_widget_checkbox_ENERGY.visible = false;
                //templateObj.$.ti_widget_container.style.height = "174px";
                return false;
            }
            templateObj.$.ti_widget_checkbox_ENERGY.disabled = false;
            templateObj.$.ti_widget_checkbox_ENERGY.visible = true;
            //templateObj.$.ti_widget_container.style.height = "220px";
            return true;
        }
	);
 	gc.databind.registry.bind('widget.ti_widget_checkbox_CHARGE.checked', 'widget.ti_model_register.$selectedDevice', 
     	function(deviceName)
     	{
            if(deviceName === "INA237_238" || deviceName === "INA239")
            {
                templateObj.$.ti_widget_checkbox_CHARGE.disabled = true;
                templateObj.$.ti_widget_checkbox_CHARGE.visible = false;
                return false;
            }
            
            templateObj.$.ti_widget_checkbox_CHARGE.disabled = false;
            templateObj.$.ti_widget_checkbox_CHARGE.visible = true;
            return true;
        }
	);
	gc.databind.registry.bind('widget.ti_widget_droplist_E1_SW1.labels', 'widget.ti_model_register.$selectedDevice', 
     	function(deviceName)
     	{
            if(deviceName === "INA229" || deviceName === "INA239")
            {
                templateObj.$.ti_widget_container_E1_SW0.visible = false;
                return "|CS1|CS2|CS3|CS4";
            }
            templateObj.$.ti_widget_container_E1_SW0.visible = true;
            return "|GND|VS|SDA|SCL";
        }
    );
    gc.databind.registry.bind('widget.ti_widget_droplist_E2_SW1.labels', 'widget.ti_model_register.$selectedDevice', 
     	function(deviceName)
     	{
            if(deviceName === "INA229" || deviceName === "INA239")
            {
                templateObj.$.ti_widget_container_E2_SW0.visible = false;
                return "|CS1|CS2|CS3|CS4";
            }
            templateObj.$.ti_widget_container_E2_SW0.visible = true;
            return "|GND|VS|SDA|SCL";
        }
	);
	gc.databind.registry.bind('widget.ti_widget_droplist_E3_SW1.labels', 'widget.ti_model_register.$selectedDevice', 
     	function(deviceName)
     	{
            if(deviceName === "INA229" || deviceName === "INA239")
            {
                templateObj.$.ti_widget_container_E3_SW0.visible = false;
                return "|CS1|CS2|CS3|CS4";
            }
            templateObj.$.ti_widget_container_E3_SW0.visible = true;
            return "|GND|VS|SDA|SCL";
        }
	);
	gc.databind.registry.bind('widget.ti_widget_droplist_E4_SW1.labels', 'widget.ti_model_register.$selectedDevice', 
     	function(deviceName)
     	{
            if(deviceName === "INA229" || deviceName === "INA239")
            {
                templateObj.$.ti_widget_container_E4_SW0.visible = false;
                return "|CS1|CS2|CS3|CS4";
            }
            templateObj.$.ti_widget_container_E4_SW0.visible = true;
            return "|GND|VS|SDA|SCL";
        }
	);
	// Bind register to variables
	gc.databind.registry.bind('ti_model_register.config_register.adcrange',	'ti_model_register.config_register.adcrange',    
	    function(value)
	    {
	        
	        if(defaultEVM === 4)
	        {
	            adcrange_EVM4 = value;
	        }
	        else if(defaultEVM === 3)
	        {
	            adcrange_EVM3 = value;
	        }
	        else if(defaultEVM === 2)
	        {
	            adcrange_EVM2 = value;
	        }
	        else //default to 1
	        {
	            adcrange_EVM1 = value;
	        }
	        
	        return value;
	    }
    );
	
});

/*
*  Boilerplate code for creating custom actions
*/
document.addEventListener('gc-nav-ready', function() 
{
    /* 
	*   Add custom actions for menu items using the following api:
	*
    *   function gc.nav.registryAction(id, runable, [isAvailable], [isVisible]);
	*
	*   param id - uniquely identifies the action, and should correspond to the action property of the menuaction widget.
	*   param runable - function that performs the custom action.
	*   param isAvailable - (optional) - function called when the menu action is about to appear.  Return false to disable the action, or true to enable it.
	*   param isVisible - (optional) - function called when the menu action is about to appear.  Return false to hide the action, or true to make it visible.
    */
	
	// For example,
	// gc.nav.registerAction('myCustomCloseAction', function() { window.close(); }, function() { return true; }, function() { return true; });
	
	// Alternatively, to programmatically disable a menu action at any time use:
	// gc.nav.disableAction('myCustomCloseAction);    then enable it again using:  gc.nav.enableAction('myCustomCloseAction'); 
});

/*
*  Boilerplate code for working with components in the application gist
*/
/**/

var initComplete = false;
//var templateObj;

// Wait for DOMContentLoaded event before trying to access the application template
var init = function() {
    templateObj = document.querySelector('#template_obj');

    // Wait for the template to fire a dom-change event to indicate that it has been 'stamped'
    // before trying to access components in the application.
	templateObj.addEventListener('dom-change',function(){
	    if (initComplete) return;
	    this.async(function(){
    	    initComplete = true;
    	    console.log("Application template has been stamped.");
  	        // Now that the template has been stamped, you can use 'automatic node finding' $ syntax to access widgets.
  	        // e.g. to access a widget with an id of 'widget_id' you can use templateObj.$.widgetId
  	        
            templateObj.$.ti_widget_button_clear_VSHUNT.addEventListener("click", function(event) {
                this.fire('clear-vshunt');
            });
            templateObj.$.ti_widget_button_save_VSHUNT.addEventListener("click", function (event) 
            {
                let numEVMs = templateObj.$.ti_widget_droplist_numEVMs.selectedValue;
                let strData0 = templateObj.$.ti_widget_scalargraph_VSHUNT.series_0_values;
                let strData1 = templateObj.$.ti_widget_scalargraph_VSHUNT.series_1_values;
                let strData2 = templateObj.$.ti_widget_scalargraph_VSHUNT.series_2_values;
                let strData3 = templateObj.$.ti_widget_scalargraph_VSHUNT.series_3_values;
                
                let result = "Sample,EVM1 VSHUNT Results";
                
                if(numEVMs > 1)
                {
                    result = result + ",EVM2 VSHUNT Results";
                }
                if(numEVMs > 2)
                {
                    result = result + ",EVM3 VSHUNT Results";
                }
                if(numEVMs > 3)
                {
                    result = result + ",EVM4 VSHUNT Results";
                }
                result = result + "\n";
                
                for (let i = 0; i < strData0.length; i++) 
                {
                    result = result + i + "," + strData0[i];
                    
                    if(numEVMs > 1)
                    {
                        result = result + "," + strData1[i];
                    }
                    if(numEVMs > 2)
                    {
                        result = result + "," + strData2[i];
                    }
                    if(numEVMs > 3)
                    {
                        result = result + "," + strData3[i];
                    }
                    result = result + "\n";
                }
                saveText("VSHUNT_Results.csv", result);
            });
            templateObj.$.ti_widget_button_clear_VBUS.addEventListener("click", function(event) {
                this.fire('clear-vbus');
            });
            templateObj.$.ti_widget_button_save_VBUS.addEventListener("click", function (event) 
            {
                let numEVMs = templateObj.$.ti_widget_droplist_numEVMs.selectedValue;
                let strData0 = templateObj.$.ti_widget_scalargraph_VBUS.series_0_values;
                let strData1 = templateObj.$.ti_widget_scalargraph_VBUS.series_1_values;
                let strData2 = templateObj.$.ti_widget_scalargraph_VBUS.series_2_values;
                let strData3 = templateObj.$.ti_widget_scalargraph_VBUS.series_3_values;
                
                let result = "Sample,EVM1 VBUS Results";
                
                if(numEVMs > 1)
                {
                    result = result + ",EVM2 VBUS Results";
                }
                if(numEVMs > 2)
                {
                    result = result + ",EVM3 VBUS Results";
                }
                if(numEVMs > 3)
                {
                    result = result + ",EVM4 VBUS Results";
                }
                result = result + "\n";
                
                for (let i = 0; i < strData0.length; i++) 
                {
                    result = result + i + "," + strData0[i];
                    
                    if(numEVMs > 1)
                    {
                        result = result + "," + strData1[i];
                    }
                    if(numEVMs > 2)
                    {
                        result = result + "," + strData2[i];
                    }
                    if(numEVMs > 3)
                    {
                        result = result + "," + strData3[i];
                    }
                    result = result + "\n";
                }
                saveText("VBUS_Results.csv", result);
            });
            templateObj.$.ti_widget_button_clear_DIETEMP.addEventListener("click", function(event) {
                this.fire('clear-dietemp');
            });
            templateObj.$.ti_widget_button_save_DIETEMP.addEventListener("click", function (event) 
            {
                let numEVMs = templateObj.$.ti_widget_droplist_numEVMs.selectedValue;
                let strData0 = templateObj.$.ti_widget_scalargraph_DIETEMP.series_0_values;
                let strData1 = templateObj.$.ti_widget_scalargraph_DIETEMP.series_1_values;
                let strData2 = templateObj.$.ti_widget_scalargraph_DIETEMP.series_2_values;
                let strData3 = templateObj.$.ti_widget_scalargraph_DIETEMP.series_3_values;
                
                let result = "Sample,EVM1 DIETEMP Results";
                
                if(numEVMs > 1)
                {
                    result = result + ",EVM2 DIETEMP Results";
                }
                if(numEVMs > 2)
                {
                    result = result + ",EVM3 DIETEMP Results";
                }
                if(numEVMs > 3)
                {
                    result = result + ",EVM4 DIETEMP Results";
                }
                result = result + "\n";
                
                for (let i = 0; i < strData0.length; i++) 
                {
                    result = result + i + "," + strData0[i];
                    
                    if(numEVMs > 1)
                    {
                        result = result + "," + strData1[i];
                    }
                    if(numEVMs > 2)
                    {
                        result = result + "," + strData2[i];
                    }
                    if(numEVMs > 3)
                    {
                        result = result + "," + strData3[i];
                    }
                    result = result + "\n";
                }
                saveText("DIETEMP_Results.csv", result);
            });
            templateObj.$.ti_widget_button_clear_CURRENT.addEventListener("click", function(event) {
                this.fire('clear-current');
            });
            templateObj.$.ti_widget_button_save_CURRENT.addEventListener("click", function (event) 
            {
                let numEVMs = templateObj.$.ti_widget_droplist_numEVMs.selectedValue;
                let strData0 = templateObj.$.ti_widget_scalargraph_CURRENT.series_0_values;
                let strData1 = templateObj.$.ti_widget_scalargraph_CURRENT.series_1_values;
                let strData2 = templateObj.$.ti_widget_scalargraph_CURRENT.series_2_values;
                let strData3 = templateObj.$.ti_widget_scalargraph_CURRENT.series_3_values;
                
                let result = "Sample,EVM1 CURRENT Results";
                
                if(numEVMs > 1)
                {
                    result = result + ",EVM2 CURRENT Results";
                }
                if(numEVMs > 2)
                {
                    result = result + ",EVM3 CURRENT Results";
                }
                if(numEVMs > 3)
                {
                    result = result + ",EVM4 CURRENT Results";
                }
                result = result + "\n";
                
                for (let i = 0; i < strData0.length; i++) 
                {
                    result = result + i + "," + strData0[i];
                    
                    if(numEVMs > 1)
                    {
                        result = result + "," + strData1[i];
                    }
                    if(numEVMs > 2)
                    {
                        result = result + "," + strData2[i];
                    }
                    if(numEVMs > 3)
                    {
                        result = result + "," + strData3[i];
                    }
                    result = result + "\n";
                }
                saveText("CURRENT_Results.csv", result);
            });
            templateObj.$.ti_widget_button_clear_POWER.addEventListener("click", function(event) {
                this.fire('clear-power');
            });
            templateObj.$.ti_widget_button_save_POWER.addEventListener("click", function (event) 
            {
                let numEVMs = templateObj.$.ti_widget_droplist_numEVMs.selectedValue;
                let strData0 = templateObj.$.ti_widget_scalargraph_POWER.series_0_values;
                let strData1 = templateObj.$.ti_widget_scalargraph_POWER.series_1_values;
                let strData2 = templateObj.$.ti_widget_scalargraph_POWER.series_2_values;
                let strData3 = templateObj.$.ti_widget_scalargraph_POWER.series_3_values;
                
                let result = "Sample,EVM1 POWER Results";
                
                if(numEVMs > 1)
                {
                    result = result + ",EVM2 POWER Results";
                }
                if(numEVMs > 2)
                {
                    result = result + ",EVM3 POWER Results";
                }
                if(numEVMs > 3)
                {
                    result = result + ",EVM4 POWER Results";
                }
                result = result + "\n";
                
                for (let i = 0; i < strData0.length; i++) 
                {
                    result = result + i + "," + strData0[i];
                    
                    if(numEVMs > 1)
                    {
                        result = result + "," + strData1[i];
                    }
                    if(numEVMs > 2)
                    {
                        result = result + "," + strData2[i];
                    }
                    if(numEVMs > 3)
                    {
                        result = result + "," + strData3[i];
                    }
                    result = result + "\n";
                }
                saveText("POWER_Results.csv", result);
            });
            templateObj.$.ti_widget_button_clear_ENERGY.addEventListener("click", function(event) {
                this.fire('clear-energy');
            });
            templateObj.$.ti_widget_button_save_ENERGY.addEventListener("click", function (event) 
            {
                let numEVMs = templateObj.$.ti_widget_droplist_numEVMs.selectedValue;
                let strData0 = templateObj.$.ti_widget_scalargraph_ENERGY.series_0_values;
                let strData1 = templateObj.$.ti_widget_scalargraph_ENERGY.series_1_values;
                let strData2 = templateObj.$.ti_widget_scalargraph_ENERGY.series_2_values;
                let strData3 = templateObj.$.ti_widget_scalargraph_ENERGY.series_3_values;
                
                let result = "Sample,EVM1 ENERGY Results";
                
                if(numEVMs > 1)
                {
                    result = result + ",EVM2 ENERGY Results";
                }
                if(numEVMs > 2)
                {
                    result = result + ",EVM3 ENERGY Results";
                }
                if(numEVMs > 3)
                {
                    result = result + ",EVM4 ENERGY Results";
                }
                result = result + "\n";
                
                for (let i = 0; i < strData0.length; i++) 
                {
                    result = result + i + "," + strData0[i];
                    
                    if(numEVMs > 1)
                    {
                        result = result + "," + strData1[i];
                    }
                    if(numEVMs > 2)
                    {
                        result = result + "," + strData2[i];
                    }
                    if(numEVMs > 3)
                    {
                        result = result + "," + strData3[i];
                    }
                    result = result + "\n";
                }
                saveText("ENERGY_Results.csv", result);
            });
            templateObj.$.ti_widget_button_clear_CHARGE.addEventListener("click", function(event) {
                this.fire('clear-charge');
            });
            templateObj.$.ti_widget_button_save_CHARGE.addEventListener("click", function (event) 
            {
                let numEVMs = templateObj.$.ti_widget_droplist_numEVMs.selectedValue;
                let strData0 = templateObj.$.ti_widget_scalargraph_CHARGE.series_0_values;
                let strData1 = templateObj.$.ti_widget_scalargraph_CHARGE.series_1_values;
                let strData2 = templateObj.$.ti_widget_scalargraph_CHARGE.series_2_values;
                let strData3 = templateObj.$.ti_widget_scalargraph_CHARGE.series_3_values;
                
                let result = "Sample,EVM1 CHARGE Results";
                
                if(numEVMs > 1)
                {
                    result = result + ",EVM2 CHARGE Results";
                }
                if(numEVMs > 2)
                {
                    result = result + ",EVM3 CHARGE Results";
                }
                if(numEVMs > 3)
                {
                    result = result + ",EVM4 CHARGE Results";
                }
                result = result + "\n";
                
                for (let i = 0; i < strData0.length; i++) 
                {
                    result = result + i + "," + strData0[i];
                    
                    if(numEVMs > 1)
                    {
                        result = result + "," + strData1[i];
                    }
                    if(numEVMs > 2)
                    {
                        result = result + "," + strData2[i];
                    }
                    if(numEVMs > 3)
                    {
                        result = result + "," + strData3[i];
                    }
                    result = result + "\n";
                }
                saveText("CHARGE_Results.csv", result);
            });
            templateObj.$.ti_widget_button_clear_all.addEventListener("click", function(event) {
                this.fire('clear-all-plots');
            });
            templateObj.$.ti_widget_button_collect_start.addEventListener("click", function(event) {
                this.fire('collect-data-plus');
            });
            templateObj.$.ti_widget_button_collect_stop.addEventListener("click", function(event) {
                this.fire('abort-collect');
            });
            templateObj.$.ti_widget_button_linkreg_EVM1.addEventListener("click", function(event) {
                this.fire('link-regmap', 1);
            });
            templateObj.$.ti_widget_button_linkreg_EVM2.addEventListener("click", function(event) {
                this.fire('link-regmap', 2);
            });
            templateObj.$.ti_widget_button_linkreg_EVM3.addEventListener("click", function(event) {
                this.fire('link-regmap', 3);
            });
            templateObj.$.ti_widget_button_linkreg_EVM4.addEventListener("click", function(event) {
                this.fire('link-regmap', 4);
            });
            templateObj.$.ti_widget_numberbox_samples_all.addEventListener("changed", function(event) {
                let samples = templateObj.$.ti_widget_numberbox_samples_all.value;
                templateObj.$.ti_widget_numberbox_samples_VSHUNT.value = samples;
                templateObj.$.ti_widget_numberbox_samples_VBUS.value = samples;
                templateObj.$.ti_widget_numberbox_samples_DIETEMP.value = samples;
                templateObj.$.ti_widget_numberbox_samples_CURRENT.value = samples;
                templateObj.$.ti_widget_numberbox_samples_POWER.value = samples;
                templateObj.$.ti_widget_numberbox_samples_ENERGY.value = samples;
                templateObj.$.ti_widget_numberbox_samples_CHARGE.value = samples;
            });
        },1);

	});
};

templateObj = document.querySelector('#template_obj');
if (templateObj) {
    init();
} else {
    document.addEventListener('DOMContentLoaded',init.bind(this))
}


